@@ -76,6 +76,7 @@ describe 'horizon' do
           "    'enable_security_group': True,",
           "    'enable_vpn': False,",
           'API_RESULT_LIMIT = 1000',
+          'DROPDOWN_MAX_ITEMS = 30',
           'TIME_ZONE = "UTC"',
           'COMPRESS_OFFLINE = True',
           "FILE_UPLOAD_TEMP_DIR = '/tmp'",
@@ -111,6 +112,7 @@ describe 'horizon' do
           :django_debug                   => true,
           :site_branding                  => 'mysite',
           :api_result_limit               => 4682,
+          :dropdown_max_items             => 123,
           :compress_offline               => false,
           :hypervisor_options             => {'can_set_mount_point' => false, 'can_set_password' => true },
           :cinder_options                 => {'enable_backup' => true },
@@ -139,6 +141,7 @@ describe 'horizon' do
           :create_image_defaults          => {'image_visibility' => 'private'},
           :password_retrieve              => true,
           :enable_secure_proxy_ssl_header => true,
+          :secure_proxy_addr_header       => 'HTTP_X_FORWARDED_FOR',
         })
       end
 
@@ -148,6 +151,7 @@ describe 'horizon' do
           "SITE_BRANDING = 'mysite'",
           "ALLOWED_HOSTS = ['some.host.tld', ]",
           "SECURE_PROXY_SSL_HEADER = ('HTTP_X_FORWARDED_PROTO', 'https')",
+          "SECURE_PROXY_ADDR_HEADER = 'HTTP_X_FORWARDED_FOR'",
           'CSRF_COOKIE_SECURE = True',
           'SESSION_COOKIE_SECURE = True',
           "  'identity': 2.0,",
@@ -198,6 +202,7 @@ describe 'horizon' do
           'OPENSTACK_ENDPOINT_TYPE = "internalURL"',
           'SECONDARY_ENDPOINT_TYPE = "ANY-VALUE"',
           'API_RESULT_LIMIT = 4682',
+          'DROPDOWN_MAX_ITEMS = 123',
           'TIME_ZONE = "Asia/Shanghai"',
           "AVAILABLE_THEMES = [",
           "  ('default', 'Default', 'themes/default'),",
@@ -249,6 +254,23 @@ describe 'horizon' do
       it { is_expected.to contain_exec('refresh_horizon_django_compress') }
     end
 
+    context 'with overridden parameters and IPv6 cache_server_ip array' do
+      before do
+        params.merge!({
+          :cache_server_ip => ['fd12:3456:789a:1::1','fd12:3456:789a:1::2'],
+        })
+      end
+
+      it 'generates local_settings.py' do
+        verify_concat_fragment_contents(catalogue, 'local_settings.py', [
+          "        'LOCATION': [ 'inet6:[fd12:3456:789a:1::1]:11211','inet6:[fd12:3456:789a:1::2]:11211', ],",
+        ])
+      end
+
+      it { is_expected.to contain_exec('refresh_horizon_django_cache') }
+      it { is_expected.to contain_exec('refresh_horizon_django_compress') }
+    end
+
     context 'with overridden parameters and cache_server_url' do
       before do
         params.merge!({
@@ -275,7 +297,7 @@ describe 'horizon' do
 
       it {
         is_expected.to contain_package('python-memcache').with(
-          :tag    => ['openstack', 'horizon-package'],
+          :tag    => ['openstack'],
           :name   => platforms_params[:memcache_package],
          )
       }
@@ -323,21 +345,23 @@ describe 'horizon' do
     context 'with ssl enabled' do
       before do
         params.merge!({
-          :listen_ssl   => true,
-          :servername   => 'some.host.tld',
-          :horizon_cert => '/etc/pki/tls/certs/httpd.crt',
-          :horizon_key  => '/etc/pki/tls/private/httpd.key',
-          :horizon_ca   => '/etc/pki/tls/certs/ca.crt',
+          :listen_ssl        => true,
+          :servername        => 'some.host.tld',
+          :horizon_cert      => '/etc/pki/tls/certs/httpd.crt',
+          :horizon_key       => '/etc/pki/tls/private/httpd.key',
+          :horizon_ca        => '/etc/pki/tls/certs/ca.crt',
+          :ssl_verify_client => 'optional',
         })
       end
 
       it 'configures apache' do
         is_expected.to contain_class('horizon::wsgi::apache').with({
-          :bind_address => nil,
-          :listen_ssl   => true,
-          :horizon_cert => '/etc/pki/tls/certs/httpd.crt',
-          :horizon_key  => '/etc/pki/tls/private/httpd.key',
-          :horizon_ca   => '/etc/pki/tls/certs/ca.crt',
+          :bind_address      => nil,
+          :listen_ssl        => true,
+          :horizon_cert      => '/etc/pki/tls/certs/httpd.crt',
+          :horizon_key       => '/etc/pki/tls/private/httpd.key',
+          :horizon_ca        => '/etc/pki/tls/certs/ca.crt',
+          :ssl_verify_client => 'optional',
         })
       end
     end
@@ -740,7 +764,7 @@ describe 'horizon' do
               :package_name     => 'openstack-dashboard',
               :root_url         => '/horizon',
               :root_path        => '/var/lib/openstack-dashboard',
-              :memcache_package => 'python-memcache',
+              :memcache_package => 'python3-memcache',
             }
           end
         when 'RedHat'
